@@ -661,10 +661,15 @@ foreign_expr_walker(Node *node,
 	return true;
 }
 
-#if (PG_VERSION_NUM >= 90600)
+#if (PG_VERSION_NUM >= 150000)
 bool is_builtin(Oid objectId)
 {
-	return (objectId < FirstBootstrapObjectId);
+        return (objectId < FirstUnpinnedObjectId);
+}
+#elif (PG_VERSION_NUM >= 90600)
+bool is_builtin(Oid objectId)
+{
+        return (objectId < FirstBootstrapObjectId);
 }
 #endif
 
@@ -1876,10 +1881,11 @@ static void
 deparseRelabelType(RelabelType *node, deparse_expr_cxt *context)
 {
 	deparseExpr(node->arg, context);
-	if (node->relabelformat != COERCE_IMPLICIT_CAST)
-		appendStringInfo(context->buf, " as %s",
-						 deparse_type_name(node->resulttype,
-										   node->resulttypmod));
+	// Pretty sure this only causes issues.
+	//if (node->relabelformat != COERCE_IMPLICIT_CAST)
+	//	appendStringInfo(context->buf, " as %s",
+	//					 deparse_type_name(node->resulttype,
+	//									   node->resulttypmod));
 }
 
 /*
